#
# spec file for package libXp
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           libXp
%define lname	libXp6
Version:        1.0.4
Release:        1.4
Summary:        X Printing Extension client library
License:        MIT
Group:          Development/Libraries/C and C++
URL:            http://xorg.freedesktop.org/

#Git-Clone:	git://anongit.freedesktop.org/xorg/lib/libXp
#Git-Web:	http://cgit.freedesktop.org/xorg/lib/libXp/
Source:         http://xorg.freedesktop.org/releases/individual/lib/%{name}-%{version}.tar.xz
Source1:        baselibs.conf
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
#git#BuildRequires:	autoconf >= 2.57, automake, libtool
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(printproto)
BuildRequires:  pkgconfig(x11) >= 1.6
BuildRequires:  pkgconfig(xau)
BuildRequires:  pkgconfig(xext)
BuildRequires:  pkgconfig(xextproto)
BuildRequires:  pkgconfig(xorg-macros) >= 1.8

%description
libXp provides APIs to allow client applications to render to
non-display devices.

%package -n %lname
Summary:        X Printing Extension client library
Group:          System/Libraries
# O/P added for 12.2
Provides:       xorg-x11-libXp = 7.6_%version-%release
Obsoletes:      xorg-x11-libXp < 7.6_%version-%release

%description -n %lname
libXp provides APIs to allow client applications to render to
non-display devices.

%package devel
Summary:        Development files for the X Printing Extension library
Group:          Development/Libraries/C and C++
Requires:       %lname = %version
# O/P added for 12.2
Provides:       xorg-x11-libXp-devel = 7.6_%version-%release
Obsoletes:      xorg-x11-libXp-devel < 7.6_%version-%release

%description devel
libXp provides APIs to allow client applications to render to
non-display devices.

This package contains the development headers for the library found
in %lname.

%prep
%setup -q

%build
%configure --disable-static
make %{?_smp_mflags}

%install
make install DESTDIR="%buildroot"
rm -f "%buildroot/%_libdir"/*.la

%post -n %lname -p /sbin/ldconfig

%postun -n %lname -p /sbin/ldconfig

%files -n %lname
%defattr(-,root,root)
%_libdir/libXp.so.6*

%files devel
%defattr(-,root,root)
%_libdir/libXp.so
%_libdir/pkgconfig/xp.pc
%_mandir/man3/*

%changelog
* Mon Sep 12 2022 Stefan Dirsch <sndirsch@suse.com>
- Update to version 1.0.4
  * Fix a memory leak on the error path in XpGetLocaleNetString
  * Update README for gitlab migration
  * Update configure.ac bug URL for gitlab migration
  * Fix spelling/wording issues
  * gitlab CI: add a basic build test
  * XpNotifyPdm.c: fix -Wmisleading-indentation warning
  * XpExtVer.c: fix -Wredundant-decls warning
  * Add deprecation notice to README
  * autogen.sh: use quoted string variables
  * autogen: add default patch prefix
  * autogen.sh: use exec instead of waiting for configure to finish
* Mon Mar  9 2015 sndirsch@suse.com
- added baselibs.conf as source to specfile in order to make
  factory checkin policy happy ...
* Sun Mar  8 2015 zaitor@opensuse.org
- Update to version 1.0.3:
  + autogen.sh: Honor NOCONFIGURE=1.
  + configure: Drop AM_MAINTAINER_MODE.
  + Remove fallback for _XEatDataWords, require libX11 1.6 for it.
* Sat Jun  1 2013 tobias.johannes.klausmann@mni.thm.de
- Update to version 1.0.2:
  This bug fix release delivers the fixes for the recently announced security
  vulnerability CVE-2013-2062, alongside the last couple years accumulation
  of janitorial cleanups, compiler warning fixes, and adjustments to remain
  compatible with changes in new and future automake releases.
* Sun Feb 17 2013 jengelh@inai.de
- Use more robust make install call
* Wed Apr 11 2012 vuntz@opensuse.org
- Update to version 1.0.1:
  + Fix compiler warnings
  + Build fixes
  + Build configuration improvements
- Add pkgconfig(xorg-macros) BuildRequires: new dependency
  upstream.
* Sun Feb 12 2012 jengelh@medozas.de
- Rename xorg-x11-libXext to libXext and utilize shlib policy
* Tue Dec 21 2010 sndirsch@novell.com
- bumped version number to 7.6
* Fri Apr  2 2010 sndirsch@suse.de
- bumped version number to 7.5
* Mon Dec 14 2009 jengelh@medozas.de
- add baselibs.conf as a source
* Sat Nov 14 2009 sndirsch@suse.de
- fixed build
* Sat May  2 2009 eich@suse.de
- revert static library and .la file removal
  for SUSE versions <= 11.1.
* Tue Apr 21 2009 crrodriguez@suse.de
- remove sttaic libraries and "la" files
- run ldconfig in postun
* Thu Sep 11 2008 sndirsch@suse.de
- bumped release number to 7.4
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Sat Sep 29 2007 sndirsch@suse.de
- bumped version to 7.3
* Thu Oct 26 2006 sndirsch@suse.de
- set version to 7.2 in specfile
* Wed Aug  2 2006 sndirsch@suse.de
- fix setup line
* Fri Jul 28 2006 sndirsch@suse.de
- use "-fno-strict-aliasing"
* Thu Jul 27 2006 sndirsch@suse.de
- use $RPM_OPT_FLAGS
* Fri Jun 23 2006 sndirsch@suse.de
- created package
